==> svelte-infinite-loading-1.1.4.tgz: package/README.md <==
<p align="center"><img src="https://raw.githubusercontent.com/Skayo/svelte-infinite-loading/master/assets/InfiniteLogo.svg" alt="InfiniteLogo" width="225"></p>
<h2 align="center">svelte-infinite-loading</h2>
<p align="center">An infinite scroll component for Svelte apps</p>
<p align="center">
  <a href="https://npmjs.com/package/svelte-infinite-loading"><img src="https://img.shields.io/npm/v/svelte-infinite-loading?style=for-the-badge" alt="NPM VERSION"></a>
  <a href="https://npmjs.com/package/svelte-infinite-loading"><img src="https://img.shields.io/npm/dt/svelte-infinite-loading?style=for-the-badge" alt="NPM DOWNLOADS"></a>
  <a href="https://npmjs.com/package/svelte-infinite-loading"><img src="https://img.shields.io/david/Skayo/svelte-infinite-loading?style=for-the-badge" alt="DEPENDENCIES"></a>
</p>
<p align="center">
  <a href="#about">About</a> •
  <a href="#features">Features</a> •
  <a href="#documentation">Documentation</a> •
  <a href="#examples">Examples</a> •
  <a href="#license">License</a>
</p>

## About

An infinite scroll component for Svelte, to help you implement an infinite scroll list more easily.  
This is heavily inspired by [vue-infinite-loading](https://peachscript.github.io/vue-infinite-loading/) and uses most of it's ideas and functionality!

### Features

- Mobile friendly
- Internal spinners
- 2-directional support
- Load result message display


## Install

With npm:
```shell
$ npm install svelte-infinite-loading
```

With yarn:
```shell
$ yarn add svelte-infinite-loading
```

Or, what I would recommend, with [pnpm](https://pnpm.js.org/):
```shell
$ npm i -g pnpm
$ pnpm install svelte-infinite-loading
```


## Documentation

You can find the documentation in the [repository wiki](https://github.com/Skayo/svelte-infinite-loading/wiki)


## Examples

- [Hacker News](https://svelte.dev/repl/c053fb0b13154b07a503ac04e0cb2c66)
- [Hacker News with Filter](https://svelte.dev/repl/73d404d5a26a47db969c4ebc154e8079)
- [Hacker News with Top Direction](https://svelte.dev/repl/9a04b19fcf5f4da0bead27f1cdf55cfb)


## License

[MIT License](https://github.com/Skayo/svelte-infinite-loading/blob/master/LICENSE.md)

==> svelte-infinite-loading-1.1.6.tgz: package/README.md <==
<p align="center"><img src="https://raw.githubusercontent.com/Skayo/svelte-infinite-loading/master/assets/InfiniteLogo.svg" alt="InfiniteLogo" width="225"></p>
<h2 align="center">svelte-infinite-loading</h2>
<p align="center">An infinite scroll component for Svelte apps</p>
<p align="center">
  <a href="https://npmjs.com/package/svelte-infinite-loading"><img src="https://img.shields.io/npm/v/svelte-infinite-loading?style=for-the-badge" alt="NPM VERSION"></a>
  <a href="https://npmjs.com/package/svelte-infinite-loading"><img src="https://img.shields.io/npm/dt/svelte-infinite-loading?style=for-the-badge" alt="NPM DOWNLOADS"></a>
  <a href="https://npmjs.com/package/svelte-infinite-loading"><img src="https://img.shields.io/david/Skayo/svelte-infinite-loading?style=for-the-badge" alt="DEPENDENCIES"></a>
</p>
<p align="center">
  <a href="#about">About</a> •
  <a href="#features">Features</a> •
  <a href="#documentation">Documentation</a> •
  <a href="#examples">Examples</a> •
  <a href="#license">License</a>
</p>

## About

An infinite scroll component for Svelte, to help you implement an infinite scroll list more easily.  
This is heavily inspired by [vue-infinite-loading](https://peachscript.github.io/vue-infinite-loading/) and uses most of its ideas and functionality!

### Features

- Mobile friendly
- Internal spinners
- 2-directional support
- Load result message display


## Install

With npm:
```shell
$ npm install svelte-infinite-loading
```

With yarn:
```shell
$ yarn add svelte-infinite-loading
```

Or, what I would recommend, with [pnpm](https://pnpm.js.org/):
```shell
$ npm i -g pnpm
$ pnpm install svelte-infinite-loading
```

### Sapper

If you're using this component in a Sapper application,
make sure to install the package to `devDependencies` rather than `dependencies`!  
[More Details](https://github.com/sveltejs/sapper-template#using-external-components)


## Examples / Demo

- [Hacker News](https://svelte.dev/repl/c053fb0b13154b07a503ac04e0cb2c66)
- [Hacker News with Filter](https://svelte.dev/repl/73d404d5a26a47db969c4ebc154e8079)
- [Hacker News with Top Direction](https://svelte.dev/repl/9a04b19fcf5f4da0bead27f1cdf55cfb)

For more information on how to use this library, check the [documentation](https://github.com/Skayo/svelte-infinite-loading/wiki)!


## Documentation

You can find the documentation in the [repository wiki](https://github.com/Skayo/svelte-infinite-loading/wiki)


## License

[MIT License](https://github.com/Skayo/svelte-infinite-loading/blob/master/LICENSE.md)
